# Merging into master
This document serves as a checklist before merging a pull request into master. This is in place because this merge
will automatically trigger a new package release. Releases require some thought after all.

## Checklist before merging 
- [ ] Documentation updated
- [ ] Config.json changes reflected in commands/get_data.validate_config
- [ ] Version number updated in pyproject.toml
- [ ] Completion script updated